import { SvelteComponent } from "svelte";
export interface HiringOrganization {
    name: string;
    sameAs: string;
    logo?: string;
}
export interface Place {
    addressLocality: string;
    addressRegion: string;
    postalCode: string;
    streetAddress: string;
    addressCountry: string;
}
export interface MonetaryAmount {
    currency: string;
    value: number | [number, number];
    unitText: UnitTextType;
}
export type UnitTextType = 'HOUR' | 'DAY' | 'WEEK' | 'MONTH' | 'YEAR';
export type EmploymentType = 'FULL_TIME' | 'PART_TIME' | 'CONTRACTOR' | 'TEMPORARY' | 'INTERN' | 'VOLUNTEER' | 'PER_DIEM' | 'OTHER';
export type OccupationalExperienceRequirements = {
    '@type'?: 'OccupationalExperienceRequirements' | 'no requirements' | string;
    minimumMonthsOfExperience: number;
};
export type EducationalOccupationalCredential = {
    '@type'?: 'EducationalOccupationalCredential' | string;
    credentialCategory: 'high school' | 'associate degree' | 'bachelor degree' | 'professional certificate' | 'postgraduate degree';
};
export type ExperienceRequirements = {
    occupational?: OccupationalExperienceRequirements;
    educational?: EducationalOccupationalCredential;
    experienceInPlaceOfEducation?: boolean;
};
export interface JobPostingJsonLdProps extends JsonLdProps {
    keyOverride?: string;
    datePosted: string;
    description: string;
    hiringOrganization: HiringOrganization;
    title: string;
    validThrough?: string;
    applicantLocationRequirements?: string;
    baseSalary?: MonetaryAmount;
    employmentType?: EmploymentType | EmploymentType[];
    jobLocation?: Place;
    jobLocationType?: string;
    experienceRequirements?: ExperienceRequirements;
}
import type { JsonLdProps } from './jsonld.js';
declare const __propDef: {
    props: {
        keyOverride?: JobPostingJsonLdProps['keyOverride'];
        datePosted: JobPostingJsonLdProps['datePosted'];
        description: JobPostingJsonLdProps['description'];
        hiringOrganization: JobPostingJsonLdProps['hiringOrganization'];
        title: JobPostingJsonLdProps['title'];
        validThrough?: JobPostingJsonLdProps['keyOverride'];
        applicantLocationRequirements?: JobPostingJsonLdProps['applicantLocationRequirements'];
        baseSalary?: JobPostingJsonLdProps['baseSalary'];
        employmentType?: JobPostingJsonLdProps['employmentType'];
        jobLocation?: JobPostingJsonLdProps['jobLocation'];
        jobLocationType?: JobPostingJsonLdProps['jobLocationType'];
        experienceRequirements?: JobPostingJsonLdProps['experienceRequirements'];
    };
    events: {
        [evt: string]: CustomEvent<any>;
    };
    slots: {};
};
export type JobPostingProps = typeof __propDef.props;
export type JobPostingEvents = typeof __propDef.events;
export type JobPostingSlots = typeof __propDef.slots;
export default class JobPosting extends SvelteComponent<JobPostingProps, JobPostingEvents, JobPostingSlots> {
}
export {};
